function [t,y] = EulerTemplate(f,T,y0,h)
% Template for the Explicit Euler method.
%
% Solves the initial value problem y'=f(t,y), y(0)=y0 up to time T
% using the explicit Euler metho and constant step size h.
%
% example:
% 1. With anonymous function for the right hand side of the diff. eq.:
%
% [t,y] = Euler(@(t,y) -5*y,5,1,0.1);
%
% 2. With a function for the right hand side defined in the MATLAB shell:
%
% g = @(t,y) -5*y;
% [t,y] = Euler(g,5,1,0.1);
%
% 3. With a function defined in its own MATLAB file "f.m":
%
% [t,y] = Euler(@f,5,1,0.1);
%
% Plot of the solution:
% plot(t,y,'x-')
%
% Notice: You ONLY have to write code for subfunction "Eulerstep". Please Modify the Function Name to "Euler" after finishing the code.
%

  t(1) = 0;
  y(1) = y0;

  N = round((T-0)/h);

  for n=1:N
    y(n+1) = eulerstep(f,t(n),y(n),h);
    t(n+1) = t(n) + h;
  end

function yn = eulerstep(f,t,y,h)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Write Explicit Euler Method here.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
